package com.brilliance.isc.funds.fttfcm.resource;

import com.brilliance.isc.bo.Bch;
import com.brilliance.isc.bo.Pta;
import com.brilliance.isc.common.cache.pta.PtaCacheService;
import com.brilliance.isc.common.context.SettleContext;
import com.brilliance.isc.common.transaction.controller.AbstractTransactionController;
import com.brilliance.isc.common.util.StringUtils;
import com.brilliance.isc.common.vo.PtsptaVo;
import com.brilliance.isc.funds.bo.funds.FttfcmStoreBo;
import com.brilliance.isc.funds.fttfcm.service.FttfcmTransactionServiceImpl;
import com.brilliance.isc.funds.transfer.transaction.FttfcmStructMapper;
import com.brilliance.isc.funds.vo.funds.FttfcmStoreVo;
import com.brilliance.isc.funds.vo.funds.FxtfcmStoreVo;
import com.brilliance.isc.funds.vo.funds.FxtfopStoreVo;
import com.brilliance.isc.transfer.IStructMapper;
import com.brilliance.isc.vo.ResponseSet;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @program: isc-funds
 * @ClassName: FttfcmResource
 * @description: 结售汇平盘确认 Fttfcm 请求入口
 * @author: xiaotong
 * @create: 2024-10-11 17:09
 */

@RestController
@RequestMapping("/fttfcm")
public class FttfcmResource extends AbstractTransactionController<FttfcmStoreVo> {

    @Resource
    private FttfcmStructMapper fttfcmStructMapper;

    public IStructMapper getStructMapper() {
        return fttfcmStructMapper;
    }

    @Resource
    FttfcmTransactionServiceImpl fttfcmTransactionService;

    @Autowired
    private PtaCacheService ptaCacheService;

    @Resource
    private SettleContext settleContext;
    /**
     * 根据结售汇类型 等获取业务参号
     *
     * @param fttfcmStoreVo
     * @return
     */
    @PostMapping("/getRef")
    public ResponseSet<String> getRef(@RequestBody FttfcmStoreVo fttfcmStoreVo) {
        FttfcmStoreBo fttfcmStoreBo= fttfcmStructMapper.voTransferToBo(fttfcmStoreVo);
        fttfcmStoreBo.reset();

        //已有ownref
        if (StringUtils.isNotEmpty(fttfcmStoreBo.getFtdgrp().getRec().getOwnref())){
            return ResponseSet.simpleSuccess(fttfcmStoreBo.getFtdgrp().getRec().getOwnref());
        }

        //Tro.ptainr为空
        PtsptaVo ptsptaVo = fttfcmStoreBo.getFtdgrp().getTro();
        if (ptsptaVo == null || StringUtils.isEmpty(ptsptaVo.getPtainr())) {
            return ResponseSet.fail("无效的客户号,请检查是否为我行客户");
            //SettleContext.getUserSession().setWrkbch(SettleContext.getUserSession().getBch());
        }

        //pta.Branchinr
        Pta pta = ptaCacheService.getPtaByInr(ptsptaVo.getPtainr());
        if (pta == null || StringUtils.isEmpty(pta.getBranchinr())) {
            return ResponseSet.fail("无效的客户号,请检查是否为我行客户和客户归属机构");
        }

        settleContext.loadSettleSession("", pta.getBranchinr(), "");
        //检查归属机构的机构号是否存在
        Bch wrkbch = SettleContext.getUserSession().getWrkbch();
        if (wrkbch == null || StringUtils.isEmpty(wrkbch.getBchflg())) {
            return ResponseSet.fail("客户所属机构未配置完整，请联系系统管理员，pta.branchinr="+pta.getBranchinr());
        }

        String ref = fttfcmTransactionService.getRef(fttfcmStoreBo);
        return ResponseSet.simpleSuccess(ref);
    }


    @PostMapping("/defaultSwtn99N1000")
    public ResponseSet<String> defaultSwtn99N1000(@RequestBody FttfcmStoreBo fttfcmStorebo) {
        fttfcmTransactionService.defaultSwtn99N1000(fttfcmStorebo);
        return ResponseSet.simpleSuccess(fttfcmStorebo);
    }


    @PostMapping("/defaultFttpTriactN1200")
    public ResponseSet defaultAcc1N1000(@RequestBody FttfcmStoreBo bo) {
        try {
            settleContext.loadSettleSession("FTTFCM","","");
            List<String> accList= fttfcmTransactionService.defaultFttpTriactN1200(bo);
            return ResponseSet.simpleSuccess(accList);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }
    }

    @PostMapping("/defaultFttpTroactN1200")
    public ResponseSet defaultAcc2N1000(@RequestBody FttfcmStoreBo bo) {
        try {
            settleContext.loadSettleSession("FTTFCM","","");
            List<String> accList= fttfcmTransactionService.defaultFttpTroactN1200(bo);
            return ResponseSet.simpleSuccess(accList);
        } catch (Exception e) {
            throw e;
        } finally {
            SettleContext.removeUserSession();
        }
    }

}
